@@ -32,4 +32,9 @@ test_that("map_tb_burden produces an interactive plot", {
   
   expect_true(!is.null(plot_int))
   expect_equal("plotly", class(plot_int)[1])
-})
\ No newline at end of file
+})
+
+test_that("map_tb_burden produces and error when multiple years are mapped with
+          interative = FALSE", {
+            expect_error(map_tb_burden(year = c(2000, 2001), interactive = FALSE))
+          })
\ No newline at end of file
